package com.qs.mp.web.controller.api.admin;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.qs.mp.admin.domain.CdKeyGroup;
import com.qs.mp.admin.domain.param.CdKeyCreateParam;
import com.qs.mp.admin.domain.param.CdKeyQueryParam;
import com.qs.mp.admin.domain.vo.CdKeyGroupListVO;
import com.qs.mp.admin.service.ICdKeyGroupService;
import com.qs.mp.common.core.domain.AjaxResult;
import com.qs.mp.common.core.page.TableDataInfo;
import com.qs.mp.common.utils.StringUtils;
import com.qs.mp.web.controller.BaseController;
import io.swagger.annotations.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;
import java.util.Objects;

/**
 * @author zhangkaikai
 * @create 2023-05-16 10:16 AM
 **/
@Api(tags = "兑换码管理API")
@RestController
@RequestMapping("/api/v1/mp/admin/CdKey/*")
public class CdKeyMgrController extends BaseController {


    @Autowired
    ICdKeyGroupService cdKeyGroupService;


    @ApiOperation("兑换码生成")
    @PreAuthorize("@ss.hasPermi('business:cdKey:add')")
    @PostMapping("/create")
    public AjaxResult create(@Validated @RequestBody CdKeyCreateParam param) {
        String groupId = cdKeyGroupService.createCdKeyGroup(param);
        if (StringUtils.isNotBlank(groupId)) {
            return AjaxResult.success();
        }
        return AjaxResult.error("生成兑换码失败");
    }

    @ApiOperation("查询所有兑换码组列表")
    @PreAuthorize("@ss.hasPermi('business:cdKey:list')")
    @PostMapping("/list")
    @ApiResponses(
            @ApiResponse(code = 200, message = "查询成功", response = CdKeyGroupListVO.class)
    )
    public TableDataInfo list(@RequestBody CdKeyQueryParam param) {

        QueryWrapper<CdKeyGroup> queryWrapper = new QueryWrapper<>();

        if (Objects.nonNull(param.getCreateTimeStart())&&Objects.nonNull(param.getCreateTimeEnd())) {
            queryWrapper.between("created_time", param.getCreateTimeStart(), param.getCreateTimeEnd());
        }

        if (Objects.nonNull(param.getActiveTimeStart())&&Objects.nonNull(param.getActiveTimeEnd())) {
            queryWrapper.between("activation_time", param.getActiveTimeStart(), param.getActiveTimeEnd());
        }

        if (Objects.nonNull(param.getMinCdKeyNum())&&Objects.nonNull(param.getMaxCdKeyNum())) {
            queryWrapper.between("quantity", param.getMinCdKeyNum(), param.getMaxCdKeyNum());
        }

        if (Objects.nonNull(param.getChannelId())) {
            queryWrapper.eq("channel_id", param.getChannelId());
        }

        if (Objects.nonNull(param.getStatus())) {
            queryWrapper.eq("status", param.getStatus());
        }

        queryWrapper.orderByDesc("FIELD(`status`,'waiting','nonactivated','activated','invalid')");
        queryWrapper.orderByDesc("created_time");

        startPage();
        List<CdKeyGroup> list = cdKeyGroupService.list(queryWrapper);
        return getDataTable(list);
    }
}
